@@ -21,7 +21,9 @@
 ##
 ################################################################################
 
-__all__ = ['init_ipython', 'install']
+__all__ = ['load_ipython_extension', 'unload_ipython_extension', 'load_config',
+           'install']
 
-from ipython_00_10 import init_ipython
+from ipython_00_11 import load_ipython_extension, unload_ipython_extension, \
+    load_config
 from ipy_install import install
\ No newline at end of file
