@@ -21,8 +21,8 @@
    
 *******************************************************************************/
 
-#include <boost/python.hpp>
-#include <tango/tango.h>
+#include "precompiled_header.hpp"
+#include <tango.h>
 
 using namespace boost::python;
 
@@ -30,6 +30,7 @@ void export_attribute_info_ex()
 {
     class_<Tango::AttributeInfoEx, bases<Tango::AttributeInfo> >
         ("AttributeInfoEx")
+        .def(init<const Tango::AttributeInfoEx&>())
         .def_readwrite("alarms", &Tango::AttributeInfoEx::alarms)
         .def_readwrite("events", &Tango::AttributeInfoEx::events)
         .def_readwrite("sys_extensions", &Tango::AttributeInfoEx::sys_extensions)
